@@ -53,11 +53,11 @@ BUF_HUBER_D0_COV_SKATERS = [buf_huber_pcov_d0_a1_b2_n50, buf_huber_pcov_d0_a05_b
 
 
 def buf_huber_pcov_d1_a1_b2_n50(y, s, k=1, e=1):
-    return d1_factory(f=buf_huber_pcov_d0_a1_b2_n50,y=y,s=s,k=k,a=1.0, b=2.0, n_buffer=50, e=e)
+    return d1_factory(f=buf_huber_pcov_d0_a1_b2_n50,y=y,s=s,k=k, n_buffer=50, e=e)
 
 
 def buf_huber_pcov_d1_a1_b2_n100(y, s, k=1, e=1):
-    return d1_factory(f=buf_huber_pcov_d0_a1_b2_n100, y=y,s=s,k=k,a=1.0, b=2.0, n_buffer=100, e=e)
+    return d1_factory(f=buf_huber_pcov_d0_a1_b2_n100, y=y,s=s,k=k,n_buffer=100, e=e)
 
 
 BUF_HUBER_D1_COV_SKATERS = [buf_huber_pcov_d1_a1_b2_n50, buf_huber_pcov_d1_a1_b2_n100]
