@@ -6,8 +6,67 @@ from collections import Counter
 import random
 from precise.skatervaluation.battleutil.speed import TIMING
 from collections import OrderedDict
+import pandas as pd
+from precise.whereami import ELO_CSV
 # Creating Elo ratings from collections of wins and losses stored in hashed files /battleresults
 
+GENRES = ['manager_var','manager_info','cov_likelihood']
+ELO_URL = 'https://raw.githubusercontent.com/microprediction/precise/main/precise/skatervaluation/battleresults/elo.csv'
+
+ELO_LIMIT = 50000
+
+
+def get_elo(genre):
+    """ Retrieve cached Elo ratings """
+    url = ELO_URL.replace('elo','elo_'+genre)
+    df = pd.read_csv(url)
+    return df
+
+
+def create_elo_csvs():
+    """ Clobber the elo_***.csv files """
+    print(ELO_CSV)
+    for genre in GENRES:
+        fn = ELO_CSV.replace('elo', 'elo_' + genre)
+        print(fn)
+        df = elo_df(genre=genre, category=None)
+        df.to_csv(fn, index=False)
+
+
+def elo_df(genre='manager_info', category='stocks'):
+    """ Elo ratings in a dataframe
+    :param genre:      'cov_likelihood'
+    :param category:
+    :return:
+    """
+    ratings = elo_from_win_files(genre=genre, category=category)
+    elo_tuples = list()
+    for r in ratings:
+        cat = r[0]
+        for strat, strat_stats in r[1].items():
+            got_it = False
+            try:
+                elo_ = strat_stats[0]
+                try:
+                    cpu_ = round(float(strat_stats[1]),1)
+                except:
+                    cpu_ = -1
+                got_it=True
+            except:
+                try:
+                    elo_ = float(strat_stats)
+                    cpu_ = -1
+                    got_it = True
+                except:
+                    got_it = False
+            if got_it:
+                _tup = (genre,cat,strat, elo_, cpu_)
+                elo_tuples.append(_tup)
+
+    df = pd.DataFrame(columns=['genre','category','strategy','elo','cpu'], data=elo_tuples)
+    return df
+
+
 
 
 def elo_from_win_files(genre='cov_likelihood', category=None):
@@ -42,11 +101,15 @@ def elo_from_win_counts(ctn, timing_genre=None):
     import time
     st = time.time()
     ct = 0
+    n_limit = ELO_LIMIT
+    n_count = 0
     while not finished:
+        n_count += 1
+
         remaining_counts = [ c for b,c in ctn.items() if c>=1 ]
         remaining_battles = [ (b,c) for b,c in ctn.items() if c>=1 ]
         weights = [ c/sum(remaining_counts) for c in remaining_counts ]
-        finished = not remaining_battles
+        finished = (not remaining_battles) or (n_count>n_limit)
         if not finished:
             n_remaining = sum(remaining_counts)
             if n_remaining % 100 ==0:
@@ -69,6 +132,6 @@ def elo_from_win_counts(ctn, timing_genre=None):
 
 
 if __name__=='__main__':
-    category_sub_string = 'stocks' # e.g. m6_daily_p100
-    ratings = elo_from_win_files(genre='manager_var', category=category_sub_string)
+    category_sub_string = 'stocks_20_days' # e.g. m6_daily_p100
+    ratings = elo_df(genre='manager_var', category=category_sub_string)
     pprint(ratings)
\ No newline at end of file
